@@ -61,6 +61,8 @@ def is_python_file(path):
     _root, ext = os.path.splitext(path)
     if ext in ('.py', '.pyi'):
         return True
+    if ext in ('.pex', ):
+        return False
 
     # Skip editor backup files.
     if path.endswith('~'):
@@ -83,7 +85,7 @@ class SortAttempt(object):
 
 def sort_imports(file_name, **arguments):
     try:
-        result = SortImports(file_name, **arguments)
+        result = SortImports(file_name, check_skip=False, **arguments)
         return SortAttempt(result.incorrectly_sorted, result.skipped)
     except IOError as e:
         print("WARNING: Unable to parse file {0} due to {1}".format(file_name, e))
@@ -97,10 +99,6 @@ def iter_source_code(paths, config, skipped):
 
     for path in paths:
         if os.path.isdir(path):
-            if should_skip(path, config, os.getcwd()):
-                skipped.append(path)
-                continue
-
             for dirpath, dirnames, filenames in os.walk(
                     path, topdown=True, followlinks=True
             ):
